OSs are now capable of treating SP and CRYPTO memory as true capabilities
and therefore these should be exposed. This requires usage of a separate
ACCESS_MASK to hide all page-access permission capabilities.
Change in masking and hiding of SP and CRYPTO was introduced in 
3bd5c994c879f78e8e3d5346dc3b627f199291aa

Signed-off-by: Malgorzata Kukiello <jacek.kukie...@intel.com>
Cc: Jian J Wang <jian.j.w...@intel.com>
Cc: Hao A Wu <hao.a...@intel.com>
Cc: Dandan Bi <dandan...@intel.com>
Cc: Liming Gao <gaolim...@byosoft.com.cn>
Cc: Oleksiy Yakovlev <oleks...@ami.com>
Cc: Ard Biesheuvel (ARM address) <ard.biesheu...@arm.com>
---
 MdeModulePkg/Core/Dxe/Mem/Page.c | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/MdeModulePkg/Core/Dxe/Mem/Page.c b/MdeModulePkg/Core/Dxe/Mem/Page.c
index 2c2c9cd6c3..731bf08bc9 100644
--- a/MdeModulePkg/Core/Dxe/Mem/Page.c
+++ b/MdeModulePkg/Core/Dxe/Mem/Page.c
@@ -1924,16 +1924,16 @@ CoreGetMemoryMap (
   //       set attributes and change memory paging attribute accordingly.
   //       But current EFI_MEMORY_DESCRIPTOR.Attribute is assigned by
   //       value from Capabilities in GCD memory map. This might cause
   //       boot problems. Clearing all paging related capabilities can
   //       workaround it. Following code is supposed to be removed once
   //       the usage of EFI_MEMORY_DESCRIPTOR.Attribute is clarified in
   //       UEFI spec and adopted by both EDK-II Core and all supported
   //       OSs.
   //
   MemoryMapEnd = MemoryMap;
   MemoryMap = MemoryMapStart;
   while (MemoryMap < MemoryMapEnd) {
-    MemoryMap->Attribute &= ~(UINT64)EFI_MEMORY_ATTRIBUTE_MASK;
+    MemoryMap->Attribute &= ~(UINT64)EFI_MEMORY_ACCESS_MASK;
     MemoryMap = NEXT_MEMORY_DESCRIPTOR (MemoryMap, Size);
   }
   MergeMemoryMap (MemoryMapStart, &BufferSize, Size);
@@ -1924,16 +1924,16 @@ CoreGetMemoryMap (
   //       But current EFI_MEMORY_DESCRIPTOR.Attribute is assigned by
   //       value from Capabilities in GCD memory map. This might cause
-  //       boot problems. Clearing all paging related capabilities can
-  //       workaround it. Following code is supposed to be removed once
-  //       the usage of EFI_MEMORY_DESCRIPTOR.Attribute is clarified in
-  //       UEFI spec and adopted by both EDK-II Core and all supported
-  //       OSs.
+  //       boot problems. Clearing all page-access permission related
+  //       capabilities can workaround it. Following code is supposed to
+  //       be removed once the usage of EFI_MEMORY_DESCRIPTOR.Attribute
+  //       is clarified in UEFI spec and adopted by both EDK-II Core and
+  //       all supported OSs.
   //
   MemoryMapEnd = MemoryMap;
-- 
2.18.0.windows.1

---------------------------------------------------------------------
Intel Technology Poland sp. z o.o.
ul. Sowackiego 173 | 80-298 Gdask | Sd Rejonowy Gdask Pnoc | VII Wydzia 
Gospodarczy Krajowego Rejestru Sdowego - KRS 101882 | NIP 957-07-52-316 | 
Kapita zakadowy 200.000 PLN.
Ta wiadomo wraz z zacznikami jest przeznaczona dla okrelonego adresata i moe 
zawiera informacje poufne. W razie przypadkowego otrzymania tej wiadomoci, 
prosimy o powiadomienie nadawcy oraz trwae jej usunicie; jakiekolwiek 
przegldanie lub rozpowszechnianie jest zabronione.
This e-mail and any attachments may contain confidential material for the sole 
use of the intended recipient(s). If you are not the intended recipient, please 
contact the sender and delete all copies; any review or distribution by others 
is strictly prohibited.
 



-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.
View/Reply Online (#65567): https://edk2.groups.io/g/devel/message/65567
Mute This Topic: https://groups.io/mt/77056341/21656
Group Owner: devel+ow...@edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub [arch...@mail-archive.com]
-=-=-=-=-=-=-=-=-=-=-=-


Reply via email to